==> bonita-server-6.1.2-sources.jar: org/bonitasoft/engine/core/process/instance/model/archive/builder/impl/SATransitionInstanceBuilderImpl.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.archive.builder.impl;

import org.bonitasoft.engine.core.process.definition.model.STransitionDefinition;
import org.bonitasoft.engine.core.process.definition.model.TransitionState;
import org.bonitasoft.engine.core.process.instance.model.SFlowNodeInstance;
import org.bonitasoft.engine.core.process.instance.model.SStateCategory;
import org.bonitasoft.engine.core.process.instance.model.archive.SATransitionInstance;
import org.bonitasoft.engine.core.process.instance.model.archive.builder.SATransitionInstanceBuilder;
import org.bonitasoft.engine.core.process.instance.model.archive.impl.SATransitionInstanceImpl;

/**
 * @author Hongwen Zang
 */
public class SATransitionInstanceBuilderImpl extends SAFlowElementInstanceBuilderImpl implements SATransitionInstanceBuilder {

    private SATransitionInstanceImpl entity;

    @Override
    public SATransitionInstanceBuilder createNewTransitionInstance(final STransitionDefinition sTransitionDefinition,
            final SFlowNodeInstance sFlowNodeInstance, final TransitionState state) {
        entity = new SATransitionInstanceImpl(sTransitionDefinition, sFlowNodeInstance);
        entity.setState(state);
        entity.setStateCategory(SStateCategory.ABORTING);
        return this;
    }

    @Override
    public SATransitionInstance done() {
        return entity;
    }

}

==> bonita-server-6.2.5-sources.jar: org/bonitasoft/engine/core/process/instance/model/archive/builder/impl/SATransitionInstanceBuilderImpl.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.archive.builder.impl;

import org.bonitasoft.engine.core.process.instance.model.archive.SATransitionInstance;
import org.bonitasoft.engine.core.process.instance.model.archive.builder.SATransitionInstanceBuilder;
import org.bonitasoft.engine.core.process.instance.model.archive.impl.SATransitionInstanceImpl;

/**
 * @author Hongwen Zang
 */
public class SATransitionInstanceBuilderImpl implements SATransitionInstanceBuilder {

    private final SATransitionInstanceImpl entity;

    public SATransitionInstanceBuilderImpl(final SATransitionInstanceImpl entity) {
        super();
        this.entity = entity;
    }

    @Override
    public SATransitionInstance done() {
        return entity;
    }

}
